Description: Illinois Courts Information Site. Contains Supreme, Appellate and Circuit Court information, including judges, and the opinions of the Supreme and Appellate Courts.

Loading

Local Court Information:
The Illinois Courts now offer two ways to be notified of news and court-related information. Illinois Courts Twitter Account E-mail List Notification
# Recent Appellate Court Opinions
Search Opinions: Loading The following opinions were uploaded to the Illinois Courts Web Site on the indicated Posted date. This listing will be maintained for 90 days at which time the oldest opinions will be moved to an Archive table. All Opinions are in PDF format. To view a PDF file you will need Adobe Acrobat Reader which is available free of charge. NRel beside case number indicates slip opinion not yet released for publication. Official Reports indicates the final, released version of the opinion. For additional information, please read A Caution on Court Opinions. Sorting Opinions: Opinions may be sorted by 'Posting Date', 'Filing Date', 'Docket #', 'Public Domain Citation #", or 'Case Name.' Click on the column name/header, the opinions will sort in descending/ascending order.
Posting Date | Filing Date | Docket # | Public Domain Citation # | Case Name (PDF)
--- | --- | --- | --- | ---
08/16/13 | 08/16/13 | 1-11-1040 NRel | 2013 IL App (1st) 111040 | People v. Marcos
08/16/13 | 08/14/13 | 1-12-1195 NRel | 2013 IL App (1st) 121195 | People v. Saleh - Corrected
08/16/13 | 08/16/13 | 1-12-2948 NRel | 2013 IL App (1st) 122948 | In re Estate of DiMatteo
08/16/13 | 08/16/13 | 1-12-3261 NRel | 2013 IL App (1st) 123261 | In re Marriage of Wendt
08/16/13 | 08/16/13 | 1-11-2746 NRel | 2013 IL App (1st) 112746 | Calloway v. Bovis Lend Lease, Inc.
08/16/13 | 08/16/13 | 5-13-0069 NRel | 2013 IL App (5th) 130069 | Walls v. The Department of Employment Security
08/14/13 | 08/14/13 | 1-12-1195 NRel | 2013 IL App (1st) 121195 | People v. Saleh
08/13/13 | 08/13/13 | 1-10-0575 NRel | 2013 IL App (1st) 100575 | People v. Chambers
08/13/13 | 08/13/13 | 4-12-0118 NRel | 2013 IL App (4th) 120118 | People v. Walker
08/13/13 | 08/12/13 | 4-12-0504 NRel | 2013 IL App (4th) 120504 | Tiller v. The Department of Children and Family Services
08/12/13 | 08/12/13 | 1-12-1375 NRel | 2013 IL App (1st) 121375 | Steinmetz v. Wolgamot
08/12/13 | 06/28/13 | 2-11-1103 Official Reports | 2013 IL App (2d) 111103 | People v. Albers
08/12/13 | 06/28/13 | 2-11-1132 Official Reports | 2013 IL App (2d) 111132 | People v. Montes
08/12/13 | 06/27/13 | 2-11-1183 Official Reports | 2013 IL App (2d) 111183 | People v. Anderson
02/01/13 | 12/31/12 | 3-11-0907WC Official Reports | 2012 IL App (3d) 110907WC | Dye v. Illinois Workers' Compensation Comm'n
02/01/13 | 12/06/12 | 4-11-0847WC Official Reports | 2012 IL App (4th) 110847WC | Venture-Newberg Perini Stone and Webster v. Illinois Workers' Compensation Comm'n
02/01/13 | 12/31/12 | 3-11-0926, 3-12-0080 cons. Official Reports | 2012 IL App (3d) 110926 | Thompson v. Policemen's Benevolent Labor Committee
01/31/13 | 01/31/13 | 1-12-2145 NRel | 2013 IL App (1st) 122145 | In re Marriage of Debra N.
### For opinions older than 90 days, please go to our Opinions Archive page.